xsdata.utils package
====================

Submodules
----------

.. toctree::
   :maxdepth: 4

   xsdata.utils.collections
   xsdata.utils.package
   xsdata.utils.text

Module contents
---------------

.. automodule:: xsdata.utils
   :members:
   :undoc-members:
   :show-inheritance:
